@@ -1,10 +1,10 @@
 import os
+import re
 import shutil
 import tkinter
 import tkinter.filedialog as filedialog
 import tkinter.messagebox as messagebox
 from configparser import ConfigParser
-import re
 
 import runner1c
 
@@ -21,7 +21,13 @@ def _ask_file_dir(element, title, open_file):
         return
 
     _delete_entry_value(element)
-    _set_entry_value(element, path)
+
+    if open_file:
+        path_for_element = path[0]
+    else:
+        path_for_element = path
+
+    _set_entry_value(element, path_for_element.replace('/', '\\'))
 
 
 def _place_ask_directory(label_text, position, open_file=False):
@@ -51,10 +57,9 @@ FORM = tkinter.Tk()
 BASE = _place_ask_directory('Путь к базе', 0)
 PLATFORM = _place_ask_directory('Путь к платформе', 40)
 REPO = _place_ask_directory('Путь к исходникам', 80)
-CFE_NAME = _place_ask_directory('Путь к feature', 120, True)
+CFE_NAME = _place_ask_directory('Путь к feature или epf', 120, True)
 THICK_CLIENT = place_checkbox('Толстый клиент', 90, 170)
 CREATE_EPF = place_checkbox('Создать epf', 210, 170)
-CREATE_CFE = place_checkbox('Создать cfe', 300, 170)
 
 
 def _set_entry_value(element, text):
@@ -70,7 +75,7 @@ def _radiobutton_change(repo_name):
     _delete_entry_value(PLATFORM)
     _delete_entry_value(REPO)
     THICK_CLIENT.set(False)
-    # noinspection PyPep8,PyBroadException
+
     try:
         _set_entry_value(BASE, CONFIG.get(repo_name, 'base'))
         _set_entry_value(PLATFORM, CONFIG.get(repo_name, 'platform'))
@@ -106,21 +111,34 @@ def _save_parameters(repo_path, base_path, platform_path, thick_client):
 
 
 def _save_git_path_for_base(base_path, repo_path):
-    txt_stream = open(base_path + '/GitPath.txt', 'w')
+    txt_stream = open(os.path.join(base_path, 'GitPath.txt'), 'w')
     txt_stream.write(repo_path)
     txt_stream.close()
 
 
-def _get_extension_name_from_feature(feature_path):
+def _get_extension_name_from_file(file_path):
+    path_for_search = file_path
+
+    if os.path.splitext(file_path)[1] == '.epf':
+        path_for_search = file_path.replace('build\\', '')
+        path_for_search = path_for_search.replace('.epf', '\\Ext\\ObjectModule.bsl')
+
     array = []
-    with open(feature_path, mode='r', encoding='utf-8') as file:
+    with open(path_for_search, mode='r', encoding='utf-8') as file:
         for name in re.compile('@Расширение.+', re.MULTILINE).findall(file.read()):
             array.append(name.replace('@', '').replace('Расширение', ''))
     file.close()
+
     return ','.join(array)
 
 
+def _folder_for_cfe_exist(repo_path):
+    return os.path.exists(os.path.join(repo_path, 'lib', 'ext'))
+
+
 def _create_base_click():
+    extension_name = None
+
     if not BASE.get():
         messagebox.showerror("Ошибка", 'Не указан путь к базе')
         return
@@ -133,31 +151,36 @@ def _create_base_click():
         messagebox.showerror("Ошибка", 'Не указан путь к исходникам')
         return
 
+    if CFE_NAME.get():
+        extension_name = _get_extension_name_from_file(CFE_NAME.get())
+        if len(extension_name) == 0:
+            messagebox.showerror("Ошибка", 'В выбраных фичах/тестах нет расширений')
+            return
+
     repo_path = REPO.get()
-    repo_path_win = repo_path.replace('/', '\\')
 
     if os.path.exists(BASE.get()):
         shutil.rmtree(BASE.get(), True)
     os.makedirs(BASE.get())
 
     arguments = ['--debug', 'base_for_test', '--path', PLATFORM.get(), '--connection', 'File=' + BASE.get(),
-                 '--folder', repo_path_win]
+                 '--folder', repo_path]
     if CREATE_EPF.get():
         arguments.append('--create_epf')
     if THICK_CLIENT.get():
         arguments.append('--thick')
-    if CREATE_CFE.get() and not CFE_NAME.get():
+    if _folder_for_cfe_exist(repo_path):
         arguments.append('--create_cfe')
 
     _save_parameters(repo_path, BASE.get(), PLATFORM.get(), THICK_CLIENT.get())
-    _save_git_path_for_base(BASE.get(), repo_path_win)
+    _save_git_path_for_base(BASE.get(), repo_path)
 
     if runner1c.core.main(arguments) == 0:
         destroy_form = True
-        if CREATE_CFE.get() and CFE_NAME.get():
+        if CFE_NAME.get():
             arguments = ['--debug', 'add_extensions', '--silent', '--path', PLATFORM.get(), '--connection',
-                         'File=' + BASE.get(), '--folder', os.path.join(repo_path_win, 'spec', 'ext'), '--name',
-                         _get_extension_name_from_feature(CFE_NAME.get())]
+                         'File=' + BASE.get(), '--folder', os.path.join(repo_path, 'spec', 'ext'), '--name',
+                         extension_name]
             if runner1c.core.main(arguments) != 0:
                 destroy_form = False
 
@@ -166,7 +189,7 @@ def _create_base_click():
 
 
 def _create_form():
-    FORM.title('Создание базы для тестов')
+    FORM.title('Создание базы для тестов ' + runner1c.__version__)
     FORM.geometry('430x200')
 
     i = 0
